@@ -803,7 +803,7 @@ class Task(AbstractModel):
 
 
 class TaskConfig(AbstractModel):
-    """从经验模版创建演练时需要配置的任务参数
+    """从经验模板创建演练时需要配置的任务参数
 
     """
 
